/*
 *  Linux kernel adaptation layers for owl wifi library.
 *  Copyright (C) 2010 HD Wireless AB
 *
 */

#ifndef OWL_SYNC_H
#define OWL_SYNC_H

#include <linux/module.h> /* for uint_t types */

#include "wl_api.h"
#ifdef OWL_AP_MODE
# include "wlap_api.h"
#else
# include "wl_wpa.h"
#endif

#include "owl_net.h"

int owl_sync_wl_init(struct owl_net *priv);
void owl_sync_wl_shutdown(struct owl_net *priv);

wl_err_t owl_sync_wl_process_rx(struct owl_net *priv,
                            char *pkt, size_t pkt_len, char **stripped_pkt, 
                            size_t *stripped_pkt_len, uint16_t *vlanid_prio);
wl_err_t owl_sync_wl_process_tx(struct owl_net *priv,
                                char *eth_hdr, 
                                size_t eth_hdr_len,
                                size_t pkt_len, 
                                char *hdr, 
                                uint16_t vlanid_prio,
                                void *pkt_handle);
wl_err_t owl_sync_wl_scan(struct owl_net *priv, struct wl_ssid_t *ssid);

int owl_sync_wl_get_current_network(struct owl_net *priv,
                                    struct wl_network_t **net);


wl_err_t owl_sync_wl_get_network_list(struct owl_net *priv,
                                      struct wl_network_list_t* netlist);
void owl_sync_put_network_list(struct wl_network_list_t *netlist);

wl_err_t owl_sync_wl_connect(struct owl_net *priv, char* ssid,
                             size_t ssid_len);

wl_err_t owl_sync_wl_connect_bssid(struct owl_net *priv,
                                   struct wl_mac_addr_t bssid);
wl_err_t owl_sync_wl_disconnect(struct owl_net *priv);
wl_err_t owl_sync_wl_get_rate(struct owl_net *priv,
                              wl_rate_t *tx, wl_rate_t *rx);
wl_err_t owl_sync_wl_set_key(struct owl_net *priv,
                             uint8_t key_idx, 
                             size_t key_len,
                             const void *key,
                             int swap,
                             const struct wl_mac_addr_t *bssid,
                             const struct wl_receive_seq_cnt_t *rsc,
                             int tx_key);

wl_err_t owl_sync_wl_add_wep_key(struct owl_net *priv,
                                 uint8_t key_idx, 
                                 size_t key_len, 
                                 const void *key, 
                                 struct wl_mac_addr_t *bssid);
wl_err_t owl_sync_wl_set_default_wep_key(struct owl_net *priv,
                                         uint8_t key_idx);
wl_err_t owl_sync_wl_delete_wep_key(struct owl_net *priv,
                                    uint8_t key_idx,
                                    struct wl_mac_addr_t *bssid);

wl_err_t owl_sync_wl_enable_ps(struct owl_net *priv);
wl_err_t owl_sync_wl_disable_ps(struct owl_net *priv);
wl_err_t owl_sync_wl_conf_ps(struct owl_net *priv,
                             uint8_t use_ps_poll, uint32_t ps_traffic_timeout,
                             uint32_t ps_delay, uint8_t rx_all_dtim,
                             uint16_t listen_interval);
void owl_sync_wl_poll(struct owl_net *priv, uint32_t tick);
/* Added to support AP mode */
int owl_sync_get_mode(void);
wl_err_t owl_sync_wlap_start(struct owl_net *priv,
                             char *ssid,
                             int ssid_len);
wl_err_t owl_sync_set_channel(struct owl_net *priv,
                              uint8_t channel);
wl_err_t owl_sync_wl_set_ssid(struct owl_net *priv, 
                              char* ssid, 
                              size_t ssid_len);
#endif
